Trait idea::NewBlockCipher [−][src]
pub trait NewBlockCipher {
type KeySize: ArrayLength<u8>;
pub fn new(key: &GenericArray<u8, Self::KeySize>) -> Self;
pub fn new_from_slice(key: &[u8]) -> Result<Self, InvalidLength> { ... }
}Instantiate a BlockCipher algorithm.
Associated Types
Loading content...Required methods
pub fn new(key: &GenericArray<u8, Self::KeySize>) -> Self[src]
Create new block cipher instance from key with fixed size.
Provided methods
pub fn new_from_slice(key: &[u8]) -> Result<Self, InvalidLength>[src]
Create new block cipher instance from key with variable size.
Default implementation will accept only keys with length equal to
KeySize, but some ciphers can accept range of key lengths.